/*==============================================================*/
/* C O M M U N I C A T I O N S   S T A T U S                    */
/*                                                              */
/* CSTAT   Version 2.1   Colin J Smith (c) April 1990           */
/*                                                              */
/* A program to read communication settings                     */
/*                                                              */
/* Written in Turbo C V1.5 (c) Borland International            */
/*==============================================================*/

/* #define MSC5 :use this to compile in Microsoft C 5.0 or 5.1  */

#include <bios.h>

#define STATUS 3             /* select - read communicaton port */

main(int argc, char *argv[])
{
    int port, selection, cstatus, result;

    if (argc != 3 && argc != 2)
        notail();

    port = atoi(argv[1]);
    selection = atoi(argv[2]);

    if (port < 1 || port > 4 || selection > 16 || selection < 0)
        notail();

#ifdef MSC5
    cstatus = _bios_serialcom(_COM_STATUS, --port, 0);
#else
    cstatus = bioscom(STATUS, 0, --port);
#endif

    if (selection == 0)
        switch (cstatus)
        {
            case 768:   exit(2);   /* port does not exist       */

            case 24576: exit(0);   /* nothing connected to port */

            default:    exit(1);   /* port is in use            */
        }

    result = cstatus >> --selection;

    result = result & 1;          /* mask off status bit        */
    exit(result);                 /* return value to ERRORLEVEL */
}

/*==============================================================*/

notail(void)
{
    printf("CSTAT Ver 2.1 (c) Colin J Smith March \'90\n");
    printf("Usage: CSTAT p   -- [1] test comms port 'p'\n");
    printf("       CSTAT p s -- [2] test comms port 'p' for status 's'\n\n");
    printf("pPORTsSTATUSĿ\n");
    printf("                                                      \n");
    printf("    1 COM1      1 Delta clear to send                 \n");
    printf("    2 COM2      2 Delta data set ready                \n");
    printf("    3 COM3      3 Trailing edge ring detector         \n");
    printf("    4 COM4      4 Delta receive line signal detector  \n");
    printf("                5 Clear to send                       \n");
    printf("                6 Data set ready                      \n");
    printf("                7 Ring indicator                      \n");
    printf("                8 Received line signal detect         \n");
    printf("                9 Data ready                          \n");
    printf("               10 Overrun error                       \n");
    printf("               11 Parity error                        \n");
    printf("               12 Framing error                       \n");
    printf("               13 Break detect                        \n");
    printf("               14 Transmit holding register empty     \n");
    printf("               15 Transmit shift register empty       \n");
    printf("               16 Time out                            \n");
    printf("                                                      \n");
    printf("ERRORLEVEL returnsĴ\n");
    printf("[1]           testing comms port p            \n");
    printf("        0 - nothing connected to comms port 'p'       \n");
    printf("        1 - comms port 'p' being used                 \n");
    printf("        2 - comms port 'p' not available to system    \n");
    printf("                                                      \n");
    printf("[2]     testing status s of comms port p      \n");
    printf("  0 - status false [NO]        1 - status true [YES]  \n");
    printf("\n");
    exit(-1);
}

/*==============================================================*/
