;=================================================================
;
; C U R S O R   C H A N G E R
;
; CURSOR   Version 2.1   Colin J Smith (c) March 1990
;
; A program to change the cursor shape
;
; SYNTAX:
;               CURSOR [ON/OFF/OFFC]
;
;          ON - switches on block cursor
;         OFF - switches on line cursor
;        OFFC - switches cursor off altogether
;
;=================================================================

first:   mov cl,b[080]          ; find length of command tail
	 cmp cl,2               ; is it too small to be valid?
         jb notail              ; exit if no command tail
         dec cl
         xor ch,ch
         mov si,082             ; move command tail to onoff#...
         mov di,onoff
         cld
         rep movsb

         mov bx,onoff           ; convert all of command tail to
again:   and b[bx],0df          ; upper case characters (mask)
         inc bx                 ; point to next character
         cmp bx,onoff5          ; converted all characters yet?
         jnz again              ; loop until all characters converted

         mov al,b[onoff]        ; check for ON option
         cmp al,'O'             ; check first character for O of ON or OFF
         jnz notail             ; finish if not O - as command was invalid
         mov al,b[onoff2]       ; check second character of command tail
         cmp al,'N'
         jz blockon             ; jump if ON option selected

         mov al,b[onoff2]       ; check for OFF option
         cmp al,'F'
         jnz notail
         mov al,b[onoff3]
         cmp al,'F'
         jnz notail             ; jump if OFF.. section not present

         mov al,b[onoff4]       ; check for OFFC option
         cmp al,'C'
         jz hideon              ; jump if OFFC option selected

         jmp blockoff           ; else jump for OFF option selected

what:    int 011h               ; finds out whether for colour or
         and ax,030h            ; mono screen
         cmp ax,030h
         jb graphics            ; if colour then use 'GRAPHICS'
         jmp mono               ; ...must be for mono then - use 'MONO'

graphics:cmp dx,0               ; if DX=0 THEN
         jz goff                ; set line cursor for colour (line) ELSE
         mov ch,0               ; START scan line for colour (block)
         mov cl,7               ; END scan line for colour (block)
         jmp setcur             ; set new cursor

goff:    mov ch,7               ; set line cursor for colour screens (line)
         mov cl,7               ; scan lines set in CH & CL (line)
         jmp setcur             ; set new cursor

mono:    cmp dx,0               ; if DX=0 THEN
         jz moff                ; set line cursor for mono (line) ELSE
         mov cx,219             ; set block cursor for mono screen (block)
         jmp setcur             ; set new cursor

moff:    mov ch,13              ; line cursor for monochrome screens
         mov cl,13              ; scan lines set in CH & CL for mono (line)
         jmp setcur             ; set new cursor

notail:  mov ah,09h             ; for when invalid option parsed
         mov dx,message         ; print the correct options available
         int 21h                ;
         int 20h                ; exit to DOS

blockoff:mov dx,0               ; set DX register to flag BLOCK OFF (line)
         jmp what

blockon: mov dx,1               ; set DX register to flag BLOCK ON  (block)
         jmp what               ; jump to find correct graphics mode

setcur:  mov ah,01h             ; select set cursor scan lines function
         int 010h               ; issue function
         int 020h               ; exit from routine

hideon:  call getcur            ; this portion destroys the cursor (blank)
         or ch,020h             ; set status bit, to blank cursor
         jmp setcur             ; set new cursor

getcur:  mov ah,3               ; get current cursor status
         mov bh,0
         int 010h
         ret                    ; return from call

;=================================================================
; Messages
;=================================================================

message: db 0D,0A,'CURSOR Ver 2.1 (c) Colin J Smith March ',39,'90',0D,0A
         db 'Usage: CURSOR switch -- selects type of cursor to set to',0D,0A,0D,0A
	 db 'switchDESCRIPTIONEXAMPLEĿ',0D,0A
	 db '                                                              ',0D,0A
	 db '   ON      sets cursor to block ',39,'',39,'             CURSOR ON     ',0D,0A
	 db '   OFF     sets cursor to original line ',39,'_',39,'     CURSOR OFF    ',0D,0A
	 db '   OFFC    hides the cursor ',39,' ',39,'                 CURSOR OFFC   ',0D,0A
	 db '                                                              ',0D,0A
         db '',0D,0A
         db '$'

onoff:   db 20
onoff2:  db 20
onoff3:  db 20
onoff4:  db 20
onoff5:  db 20

;=================================================================
