;=================================================================
;
; F A D E
;
; FADE   Version 2.1   Colin J Smith (c) March 1990
;
; A program to fade erase text screen displays, both monochrome and colour
;
; SYNTAX:
;               FADE s c<R>     -- <R> is the <RETURN> key
;
; where 's' is the speed (1-9) and 'c' is the character to clear the screen to
;
; e.g.          FADE 1 _<R>     -- clears screen to underlines (slowly)
;               FADE 9  <R>     -- clears screen to spaces (quickly)
;
;=================================================================

start:  push es                 ; save current extra segment
        mov es,ds               ; save data segment
        mov cl,b[080]           ; find length of command tail
        cmp cl,2                ; does a tail exist?
        jb notail               ; exit if there is no tail
        mov al,b[082]           ; get command line parameter
        sub al,48               ; find value of speed chosen
        mov [082],al            ; put back the value
        mov bl,1                ; check if value is between 1 - 9

next:   cmp al,bl
        jz begin                ; jump if 'speed' is valid
        inc bl
        cmp bl,10
        jb next

                                ; mode was invalid, so remind syntax
notail: mov  ah,09              ; specify function, print a message
        mov  dx,message         ; give location of message to print
        int  021h               ; call routine to perform function
        mov  al,255             ; get ready to exit (ERRORLEVEL = 255)
        jmp  exit

begin:  mov  ah,0fh             ; call funtion to find whether mono or colour
        int  10h                ; screen being used
        mov  si,07d0h           ; set counter to length of screen
        mov  bx,0b000h          ; set segment for monochrome mode
        cmp  al,07h             ; in monochrome mode 7?
        jz   loop0              ; then ok
        mov  bx,0b800h          ; set segment for colour mode
        cmp  al,03h             ; is the mode 3 or less?
        jg   exit               ; if not 0,1,2 or 3 then invalid mode - exit
        cmp  al,01h             ; in mode 1 or less?
        jg   loop0              ; if not mode 0 or 1 then no length adjustment
        sub  si,255             ; screen length is shorter so adjust

loop0:  mov  dl,b[084]          ; the selected character to clear with
        cmp  cl,2               ; is there only one parameter?
        jne  skip               ; if not then get character chosen
        mov  dl,020h            ; else default to space

skip:   mov  dh,07h             ; attribute to clear with (fixed)
        mov  ds,bx              ; set data segment to screen segment

loop1:  mov  cx,si              ; initialise loop counter
        xor  bx,bx              ; zeroise
        xor  di,di              ; zeroise

loop2:  mov  ax,[di]            ; get character at screen position
        cmp  ax,dx              ; already fading character?
        jz   loop5              ; then skip changing it again
        mov  ah,07h             ; attribute = 07h
        cmp  al,dl              ; is screen char above or below = fade char
        jnge loop3              ; if screen char is less than fade char
        sub  al,es:[0082]       ; change screen character (downwards)
        jmp  loop4              ; go and make the change

loop3:  inc  al                 ; change screen character (upwards)

loop4:  mov  [di],ax            ; replace character at screen position
        inc  bx                 ; counter for every combination (255 x 255)

loop5:  add  di,2               ; next character (skip attribute)
        loop loop2              ; onto the next character
        cmp  bx,+00h            ; check for every ASCII character faded
        jnz  loop1              ; next screen scan pass

        mov  al,0               ; things seem OK!
exit:   mov  ds,es              ; get back the correct data segment
        pop  es                 ; get back the extra segment
        mov  ah,04ch            ; specify function, exit
        int  021h               ; call routine to perform function

;=================================================================
; Message
;=================================================================

message: db 0D,0A,'FADE Ver 2.1 (c) Colin J Smith March ',39,'90',0D,0A
         db 'Usage: FADE s c -- selects speed of fade ',39,'s',39,' with character to clear ',39,'c',39,0D,0A,0D,0A
         db 'sSPEEDcCHARACTEREXAMPLEĿ',0D,0A
         db '                                                                          ',0D,0A
         db '  1  SLOW      ?  ANY CHARACTER    FADE 1  <R> -- clears with spaces      ',0D,0A
         db '  .                                FADE 4 *<R> -- clears with asterisks   ',0D,0A
         db '  .                                FADE 9 <R> -- clears with blocks      ',0D,0A
         db '  9  FAST                          FADE 3 _<R> -- clears with underlines  ',0D,0A
         db '                                                                          ',0D,0A
         db 'ERRORLEVEL returnsĴ',0D,0A
         db '                m - the screen mode if its invalid (not text)             ',0D,0A
         db '  0 - everything was OK                   255 - invalid no of parameters  ',0D,0A
         db '',0D,0A
         db '$'

;=================================================================
