/*==============================================================*/
/* G E T   V E C T O R   I N F O R M A T I O N                  */
/*                                                              */
/* GETVECT   Version 2.1   Colin J Smith (c) March 1990         */
/*                                                              */
/* A program to display 'System Interrupt Vector Information'   */
/*                                                              */
/* Written in Turbo C V1.5 (c) Borland International            */
/*==============================================================*/

#include <dos.h>

#define GETVECTOR 0x35      /* the get vector function call          */

main(int argc, char *argv[])
{
    unsigned int intnum;    /* value of first argument               */
    unsigned int intnum2;   /* value of second argument if present   */

    unsigned long absol;    /* the absolute interrupt Vector address */

    int intloop;            /* to hold interrupt number in loop      */

    union REGS iregs,oregs; /* to pass values to low level calls     */

    struct SREGS segreg;

                                   /* if no command tail then finish */
    if (argc < 2)                  
        notail();

                                          /* find first argument - i */
    intnum = strtol(argv[1],&argv[1]+strlen(&argv[1]),0);
    intnum2 = intnum;

              /* find second argument j - if there are more than one */
    if (argc > 2)
        intnum2 = atoi(argv[2]);

                         /* if second argument not greater or equal  */
    if (intnum2 < intnum)
        notail();        /* then exit e.g. GETVECT 23 12 - invalid   */

                         /* if there is no second argument but there */
    if (intnum2 == 0)
        intnum2 = intnum;/* is a 1st then only one Vector to display */

                                      /* if an invalid interrupt was */
    if (intnum > 255 || intnum2 > 255)
        notail();                              /* chosen then finish */

    intloop = intnum;    /* first interrupt to display details about */

    printf("ͻ\n");
    printf("  INTERRUPT NO.    SEGMENTED ADDRESS        ABSOLUTE ADDRESS       \n");
    printf("Ķ\n");
    printf(" Dec  Oct  Hex     Segment:Offset        Dec      Oct      Hex \n");
    printf("͹\n");

    while (intloop <= intnum2)
    {
        if (intloop > 255 || intloop < 0)
            notail();
        iregs.h.al = intloop;      /* put interrupt number into AL   */
        iregs.h.ah = GETVECTOR;    /* specify get interrupt function */
        intdosx(&iregs, &oregs, &segreg);           /* call function */

                            /* find absolute value of vector address */
        absol = ((unsigned long) segreg.es << 4) + oregs.x.bx;

                       /* print Vector address details for interrupt */
        printf(" %3d  %03o  %02XH       %04XH:%04XH     %7ld  %07lo  %06lXH \n",intloop,intloop,intloop, segreg.es, oregs.x.bx,absol,absol,absol);
        intloop++;
    }
    printf("ͼ\n");
}

/*=============================================================*/

notail(void)
{
    printf("\nGETVECT Ver 2.1 (c) Colin J Smith March \'90\n");
    printf("Usage: GETVECT i   -- gets vector info for interrupt 'i'\n");
    printf("       GETVECT i j -- gets vector info for interrupts 'i' to 'j'\n\n");
    printf("i&jEXAMPLEĿ\n");
    printf("                                                                     \n");
    printf("  Dec    Hex    Octal    GETVECT 2       - lists int dec 2           \n");
    printf("  ---    ---    -----    GETVECT 0XFF    - lists int dec 255         \n");
    printf("  0      0x0    00       GETVECT 20 100  - lists int dec 20,21..100  \n");
    printf("  .      .      .        GETVECT 07 010  - lists int dec 7..8        \n");
    printf("  .      .      .        GETVECT 0xF 020 - lists int dec 15..16      \n");
    printf("  255    0xff   0377     GETVECT 0x10    - lists int dec 16          \n");
    printf("                                                                     \n");
    printf("\n");
    exit(-1);
}

/*==============================================================*/
