/*==============================================================*/
/* M O U S E   M A N A G E R                                    */
/*                                                              */
/* MM   Version 2.1   Colin J Smith (c) March 1990              */
/*                                                              */
/* A program to manage the PC mouse (Microsoft compatible)      */
/*                                                              */
/* Written in Turbo C V1.5 (c) Borland International            */
/*==============================================================*/

/* #define MSC5 :use this to compile in Microsoft C 5.0 or 5.1  */

#include <dos.h>

#define MOUSEINT 0x33        /* the mouse interrupt */

main(int argc, char *argv[])
{
    void interrupt (*address)();

    int fnum, snum, tnum;
    union REGS iregs, oregs; /* define registers */

    if (argc == 1)           /* if no arguments  */
        notail();            /* display usage    */

    fnum = atoi(argv[1]);    /* first argument   */
    snum = atoi(argv[2]);    /* second argument  */
    tnum = atoi(argv[3]);    /* third argument   */

    switch (fnum)
    {
        case 1:

#ifdef MSC5
    address = _dos_getvect(MOUSEINT);
#else
    address = getvect(MOUSEINT);
#endif

                if (address == 0)
                    exit(255);

                iregs.h.al = 0; /* reset driver and check mouse */
                iregs.h.ah = 0;
                int86(MOUSEINT, &iregs, &oregs);
                if (oregs.h.al == 0)
                    exit(255);              /* no mouse driver  */
                else
                    exit(oregs.x.bx);   /* mouse driver present */
                break;

        case 2: iregs.x.ax = 2 - snum;             /* set mouse */
                int86(MOUSEINT, &iregs, &oregs);      /* ON/OFF */
                break;

        case 3: iregs.x.ax = 0xe - snum; /* light pen emulation */
                int86(MOUSEINT, &iregs, &oregs);      /* ON/OFF */
                break;

        case 4: iregs.x.ax = 3;            /* get button status */
                int86(MOUSEINT, &iregs, &oregs);
                oregs.x.bx = (oregs.x.bx >> --snum) & 1;
                exit(oregs.x.bx);

        case 5: do
                {
                    iregs.x.ax = 3;
                    int86(MOUSEINT, &iregs, &oregs);
                    oregs.x.bx = (oregs.x.bx >> (snum - 1)) & 1;
                }
                while (oregs.x.bx == 0);

        case 6: iregs.x.ax = 0x13;   /* set new acceleration    */
                iregs.x.dx = snum;   /* for mouse movements     */
                int86(MOUSEINT, &iregs, &oregs);
                break;

        case 7: iregs.x.ax = 0x0a;
                iregs.x.bx = 1;      /* change mouse cursor     */
                iregs.x.cx = snum;   /* cursor start scan-line  */
                iregs.x.dx = tnum;   /* cursor finish scan-line */
                int86(MOUSEINT, &iregs, &oregs);
                break;

        case 8: iregs.x.ax = 0x0f;   /* Set new mickeys to pixel ratio */
                iregs.x.cx = snum;   /* New X mickeys/pixel */
                iregs.x.dx = tnum;   /* New Y mickeys/pixel */
                int86(MOUSEINT, &iregs, &oregs);
                break;

        case 9: iregs.x.ax = 7;      /* Set new X min & max pos */
                iregs.x.cx = snum;   /* The new min X position  */
                iregs.x.dx = tnum;   /* The new max X position  */
                int86(MOUSEINT, &iregs, &oregs);
                break;

        case 10:iregs.x.ax = 8;      /* Set new Y min & max pos */
                iregs.x.cx = snum;   /* The new min Y position  */
                iregs.x.dx = tnum;   /* The new max Y position  */
                int86(MOUSEINT, &iregs, &oregs);
                break;
    }
}

/*==============================================================*/

notail(void)
{
    printf("\nMM - Mouse Manager Ver 2.1 (c) Colin J Smith March \'90\n");
    printf("Usage: MM o n n n .. -- selects option with specified settings n n ..\n\n");
    printf("oOPTIONEXAMPLEĿ\n");
    printf("                                                                             \n");
    printf("  1  Check and reset mouse #1  ............................ - MM 1         \n");
    printf("  2  Set mouse cursor status  1-On 0-Off................[s] - MM 2 1       \n");
    printf("  3  Set light pen emulation status  1-On 0-Off.........[s] - MM 3 1       \n");
    printf("  4  Get button status #2  1-Left 2-Right 3-Centre......[s] - MM 4 2       \n");
    printf("  5  Wait for button  1-Left 2-Right 3-Centre...........[s] - MM 5 1       \n");
    printf("  6  Set acceleration speed threshold  mickeys/sec......[m] - MM 6 2       \n");
    printf("  7  Set hardware cursor scanline  begin end........[b] [e] - MM 7 0 14    \n");
    printf("  8  Set X & Y motion/pixel ratio  mickeys/pixel....[X] [Y] - MM 8 1 2     \n");
    printf("  9  Set New Min & Max X position  ...........[Xmin] [Xmax] - MM 9 0 639   \n");
    printf(" 10  Set New Min & Max Y position  ...........[Ymin] [Ymax] - MM 10 0 199  \n");
    printf("                                                                             \n");
    printf("ERRORLEVEL returnsĴ\n");
    printf(" #1             255 - no mouse             n - number of buttons (1, 2 or 3) \n");
    printf("                                                                             \n");
    printf(" #2               0 - button up            1 - button depressed              \n");
    printf("\n");
    exit(-1);
}

/*==============================================================*/
