/*==============================================================*/
/* P R I N T E R   S T A T U S                                  */
/*                                                              */
/* PSTAT   Version 2.1   Colin J Smith (c) March 1990           */
/*                                                              */
/* A program to read printer and parallel port settings         */
/*                                                              */
/* Written in Turbo C V1.5 (c) Borland International            */
/*==============================================================*/

/* #define MSC5 :use this to compile in Microsoft C 5.0 or 5.1  */

#include <bios.h>

#define STATUS 2

#define IOE 3   /* shift for Input/Output Error */
#define SEL 4   /* shift for SELection          */
#define OOP 5   /* shift for Out Of Paper       */
#define ACK 6   /* shift for ACKnowledge        */
#define BUS 7   /* shift for not BUSy           */

main(int argc, char *argv[])
{
    int port, selection, pstatus, result;

    if (argc < 2)
        notail();

    port = atoi(argv[1]);
    selection = atoi(argv[2]);

#ifdef MSC5
    pstatus = _bios_printer(_PRINTER_STATUS, --port, 0);
#else
    pstatus = biosprint(STATUS, 0, --port);
#endif

    switch (selection)
    {
        case 0: if (pstatus == 200)  /* printer connected and switched OFF */
                    exit(0);
                if (pstatus == 48)   /* printer not connected to port      */
                    exit(3);
                if (pstatus == 2)    /* port does not exist                */
                    exit(2);
                exit(1);             /* printer connected and switched ON  */
                break;

        case 1: result = (pstatus);
                break;

        case 2: result = (pstatus >> IOE);
                break;

        case 3: result = (pstatus >> SEL);
                break;

        case 4: result = (pstatus >> OOP);
                break;

        case 5: result = (pstatus >> ACK);
                break;

        case 6: result = (pstatus >> BUS);
	}

    result = result & 1;    /* mask off status bit */
    exit(result);           /* return value to ERRORLEVEL */
}

/*==============================================================*/

notail(void)
{
    printf("PSTAT Ver 2.1 (c) Colin J Smith March \'90\n");
    printf("Usage: PSTAT p   -- [1] test printer port 'p'\n");
    printf("       PSTAT p s -- [2] test printer on port 'p' for status 's'\n\n");
    printf("pPORTsSTATUSĿ\n");
    printf("                                                      \n");
    printf("       1     LPT1 [PRN]      1     Device time out?   \n");
    printf("       2     LPT2            2     I/O error?         \n");
    printf("       3     LPT3            3     Selected?          \n");
    printf("       4     LPT4            4     Out of paper?      \n");
    printf("                             5     Acknowledge?       \n");
    printf("                             6     Not busy?          \n");
    printf("                                                      \n");
    printf("ERRORLEVEL returnsĴ\n");
    printf("[1]          testing printer port p           \n");
    printf("  0 - printer connected to port 'p' and switched OFF  \n");
    printf("  1 - printer connected to port 'p' and switched ON   \n");
    printf("  2 - port 'p' not available to system                \n");
    printf("  3 - printer not connected to port 'p'               \n");
    printf("                                                      \n");
    printf("[2] testing status s of printer on port p     \n");
    printf("  0 - status false [NO]        1 - status true [YES]  \n");
    printf("\n");
    exit(-1);
}

/*==============================================================*/
